# About Me

By day I confabulate wapdoodles and at night I subvorbify langfettled mees.

## Background

- I am a 25th level half-kobold warrior-mage
- I possess an enchanted kobold dagger called "The Pheasant Plucker"
- I played a small but crucial role in the overthrow and gory death of the witch-king N'fer Laysaut and the subsequent destruction of his undead hordes
- I blame my mother

## Skills

- Wapdoodle confabulation
- Mees subvorbification

## Favorite Things

- Belgian beer
- Peaty single-malt whiskey
- Cheesy chips and gravy
- Gruffalo crumble

## blogroll

- About
- Resume

## social

- atom feed
- GitHub
- Twitter